@@ -9,4 +9,8 @@ sub BarAndBAZ { }
 
 sub _Bar { }
 
+sub FOO { }
+
+sub FOObar { }
+
 1;
